/****************************************************************
 *								*
 * Copyright (c) 2001-2022 Fidelity National Information	*
 * Services, Inc. and/or its subsidiaries. All rights reserved.	*
 *								*
 *	This source code contains the intellectual property	*
 *	of its copyright holder(s), and is made available	*
 *	under a license.  If you do not know the terms of	*
 *	the license, please stop and do not read further.	*
 *								*
 ****************************************************************/

#ifndef MUCBLKINI_INCLUDED
#define MUCBLKINI_INCLUDED

void mucblkini(enum db_ver desired_db_ver);

#endif /* MUCBLKINI_INCLUDED */
